"""
/***************************************************************************
Name            :  help_controller.py
Description     :  A class for help icon
copyright       :  (C) 2019-2023 by FEWS
email           :  minxuansun@contractor.usgs.gov
Created         :  03/23/2020 Minxuan Sun
Modified        :  10/06/2022 - cholen - Update manual, add Spanish version
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
"""
import os

from PyQt5.QtWidgets import QAction, QMenu

from fews_tools.controllers.about_controller import AboutController


class HelpController:
    """
    Class GeoClIM Help Controller
    """

    def __init__(self, iface):
        """
        Constructor - Add menu to the Help icon
        """
        self.menu = QMenu()
        action_about = QAction('About', iface.mainWindow())
        action_about.triggered.connect(self.about)
        self.menu.addAction(action_about)

        action_view_english_geoclim_manual = QAction(
            'View GeoCLIM Manual(English)', iface.mainWindow())
        action_view_english_geoclim_manual.triggered.connect(
            self.view_english_geoclim_manual)
        self.menu.addAction(action_view_english_geoclim_manual)

        action_view_spanish_geoclim_manual = QAction(
            'View GeoCLIM Manual(Spanish)', iface.mainWindow())
        action_view_spanish_geoclim_manual.triggered.connect(
            self.view_spanish_geoclim_manual)
        self.menu.addAction(action_view_spanish_geoclim_manual)

    @staticmethod
    def about():
        """
        Static method used to open GeoCLIM about form
        """
        about_dlg = AboutController()
        about_dlg.exec_()

    @staticmethod
    def view_english_geoclim_manual():
        """
        Static method used to open the English manual
        :return:
        """
        MANUAL_ENGLISH = "GeoCLIM_3.1.0_QGIS_Manual_English.pdf"
        os.startfile(
            os.path.join(os.path.dirname(__file__), "..", "static", MANUAL_ENGLISH))

    @staticmethod
    def view_spanish_geoclim_manual():
        """
        Static method used to open the Spanish manual
        :return:
        """
        MANUAL_SPANISH = "GeoCLIM_3.0.19_QGIS_Manual_Spanish.pdf"
        os.startfile(
            os.path.join(os.path.dirname(__file__), "..", "static", MANUAL_SPANISH))

    def get_menu(self):
        """
        Menu getter
        """
        return self.menu
