"""
/***************************************************************************
Name            :  wrsi_help_controller.py
Description     :  A class for wrsi help icon
copyright       :  (C) 2022 - 2023 by FEWS
email           :  cholen@contractor.usgs.gov
Created         :  07/12/2022 Cheryl Holen
Modified        :  MM/DD/YYYY - <developer> - Description
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
"""
import os

from PyQt5.QtWidgets import QAction, QMenu

from fews_tools.controllers.about_geowrsi_controller import AboutGeoWRSIController

class WRSIHelpController:
    """
    GeoWRSI help controller class.  Will not show version here.
    """

    def __init__(self, iface):
        """
        Constructor - Add menu to the Help icon
        """
        self.menu = QMenu()
        action_about = QAction('About', iface.mainWindow())
        action_about.triggered.connect(self.about)
        self.menu.addAction(action_about)

        action_view_english_geowrsi_manual = QAction(
            'View GeoWRSI Manual(English)', iface.mainWindow())
        action_view_english_geowrsi_manual.triggered.connect(
            self.view_english_geowrsi_manual)
        self.menu.addAction(action_view_english_geowrsi_manual)

        # action_view_spanish_geowrsi_manual = QAction(
        #     'View GeoWRSI Manual(Spanish)', iface.mainWindow())
        # action_view_spanish_geowrsi_manual.triggered.connect(
        #     self.view_spanish_geowrsi_manual)
        # self.menu.addAction(action_view_spanish_geowrsi_manual)

    @staticmethod
    def about():
        """
        Static method used to open GeoWRSI about form
        """
        about_dlg = AboutGeoWRSIController()
        about_dlg.exec_()

    @staticmethod
    def view_english_geowrsi_manual():
        """
        Static method used to open the English manual
        :return:
        """
        MANUAL_ENGLISH = "UPDATED_Quick-start Guide to the GeoWRSI v3.pdf"
        os.startfile(
            os.path.join(os.path.dirname(__file__), "..", "static", MANUAL_ENGLISH))

    # @staticmethod
    # def view_spanish_geowrsi_manual():
    #     """
    #     Static method used to open the Spanish manual
    #     :return:
    #     """
    #     MANUAL_SPANISH = "GeoWRSI_3.1.0_QGIS_Manual_Spanish.pdf"
    #     os.startfile(
    #         os.path.join(os.path.dirname(__file__), MANUAL_SPANISH))

    def get_menu(self):
        """
        Menu getter
        """
        return self.menu
